applied-science.darkstar


engineclj


make-js-fnclj

(make-js-fn js-text)

vega-lite->vegaclj


vega-lite-spec->svgclj

(vega-lite-spec->svg vega-lite-spec-json-string)

Converts vega-lite-spec-json-string to a full Vega spec, then uses Vega to render the SVG described by that spec.

Converts `vega-lite-spec-json-string` to a full Vega spec, then uses Vega to render the SVG described by that spec.
raw docstring

vega-spec->svgclj

(vega-spec->svg vega-spec-json-string)

Calls Vega to render the spec in vega-spec-json-string to the SVG described by that spec.

Calls Vega to render the spec in `vega-spec-json-string` to the SVG described by that spec.
raw docstring

vega-spec->viewclj


view->svgclj

cljdoc builds & hosts documentation for Clojure/Script libraries