(make-js-fn js-text)(vega-lite-spec->svg vega-lite-spec-json-string)Converts vega-lite-spec-json-string to a full Vega spec, then uses Vega to render the SVG described by that spec.
Converts `vega-lite-spec-json-string` to a full Vega spec, then uses Vega to render the SVG described by that spec.
(vega-spec->svg vega-spec-json-string)Calls Vega to render the spec in vega-spec-json-string to the SVG described by that spec.
Calls Vega to render the spec in `vega-spec-json-string` to the SVG described by that spec.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |